@@ -20,6 +20,10 @@ Main = function ( options ) {
 	// add info from package.json
 	this.options.package = package;
 	this.options.files = [];
+	// preserve namespace
+
+	this._this = this;
+	return this;
 };
 
 Main.prototype = {
@@ -37,13 +41,14 @@ Main.prototype = {
 	load: function ( file, callback ) {
 
 		var self = this;
-
+		// save file list
 		this.options.files.push( file );
+		var files = this.options.files;
 
 		fs.readFile(file, 'utf8', function( err, obj ){
-			if( err ) console.log( err );
+			if( err ) return console.log( err );
 			// convert the response to json
-			self.data = self.parse( obj );
+			self.data = self.parse( obj, files );
 			// output the result (for the callback)
 			if ( callback ) callback( self.data );
 
@@ -77,6 +82,7 @@ Main.prototype = {
 		if( !fs.existsSync(source) ) return console.log("Couldn't find "+ source);
 		//
 		var self = this;
+
 		//set type to ascii
 		this.set({ type : "binary" });
 		// load the OBJ file
@@ -126,4 +132,6 @@ Main.prototype = {
 
 };
 
-module.exports  = new Main();
\ No newline at end of file
+module.exports  = function( options ){
+	return new Main( options );
+}
\ No newline at end of file
