@@ -3,7 +3,7 @@ var material_parser = require('./material');
 
 //OBJ parser
 
-module.exports = function ( data ){
+module.exports = function ( data, files ){
 	var vertices = [],
 	normals = [],
 	uvs = [],
@@ -170,11 +170,12 @@ module.exports = function ( data ){
 		}
 
 	// post processing
-	// - include material information
-	materials = material_parser( this.options.files.pop(), materials );
+	// - include material information (create loop for more than one files)
+	materials = material_parser( files[0], materials );
 
 	// final result
 	return {
+		files: files,
 	// counts
 		verticesCount : verticesCount,
 		faceCount : faceCount,
